###
### oc_channelconf.py
###
### Copyright (C) 2003 Ximian, Inc.
###
### This program is free software; you can redistribute it and/or
### modify it under the terms of version 2 of the GNU General Public
### License as published by the Free Software Foundation.
###
### This program is distributed in the hope that it will be useful,
### but WITHOUT ANY WARRANTY; without even the implied warranty of
### MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
### GNU General Public License for more details.
### 
### You should have received a copy of the GNU General Public License
### along with this program; if not, write to the Free Software
### Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
### USA.

import string, sys, gzip, os
import redcarpet

import oc_conffile, oc_util

class ChannelConf(oc_conffile.ConfFile):

    def __init__(self):
        oc_conffile.ConfFile.__init__(self)

        self.add_known_key("ChannelID")
        self.add_known_key("Name")
        self.add_known_key("Alias")
        self.add_known_key("Description")
        self.add_known_key("Priority")
        self.add_known_key("IconPath")
        self.add_known_key("PackagePath")


    def pre_process(self):
        self.__channel_xml = []
    
    def store_channel_info(self, distro, pkginfo_file):
        default_id = "%s-%s" % (len(self.__channel_xml), distro)

        if self.has_key("IconPath"):
            icon_path = self.relative_path(self.get("IconPath"))
        else:
            icon_path = None

        pkginfo_file = self.relative_path(pkginfo_file)
        pkg_dir      = os.path.dirname(pkginfo_file)
        pkginfo_file = os.path.basename(pkginfo_file)

        props = ( ( "id",                 self.get("ChannelID", default_id) ),
                  ( "name",               self.get("Name")                  ),
                  ( "alias",              self.get("Alias")                 ),
                  ( "description",        self.get("Description")           ),
                  ( "distro_target",      distro                            ),
                  ( "priority",           self.get("Priority")              ),
                  ( "pub",                "t"                               ),
                  ( "path",               pkg_dir                           ),
                  ( "subs_url",           None                              ),
                  ( "unsubs_url",         None                              ),
                  ( "icon",               icon_path                         ),
                  #( "file_path",          pkg_dir                           ),
                  ( "pkginfo_file",       pkginfo_file                      ),
                  ( "pkginfo_compressed", "1"                               ),
                  )

        def prop_to_str(x):
            if x is None:
                return ""
            key, val = x
            if key is None or val is None:
                return ""
            return '%s="%s"' % (key, val)
        props_str = string.join(map(prop_to_str, props), " ")

        self.__channel_xml.append("<channel %s/>" % props_str)


    def write_pkginfo(self, pkg_path):

        norm_pkg_path = self.normalize_path(pkg_path)
        packages = oc_util.get_packages(norm_pkg_path)

        pkginfo_file = os.path.join(pkg_path, "packageinfo.xml.gz")
        pkginfo_file = self.normalize_path(pkginfo_file)

        fh = gzip.open(pkginfo_file, "wb")

        fh.write("<?xml version=\"1.0\"?>\n\n")
        fh.write("<channel>\n")
        fh.write("<subchannel name=\"subchannel\" priority=\"100\">\n")

        for pkg in packages:
            fh.write(pkg.to_xml())
            fh.write("\n")

        fh.write("</subchannel>\n")
        fh.write("</channel>\n")

        return pkginfo_file
            

    def process_adddistro(self, val):
        args = map(string.strip, val.split(" "))

        if len(args) == 0:
            self.error("Too few arguments to AddDistro")
        elif len(args) == 1:
            distro = args[0]
            pkg_path = args[0]
        elif len(args) == 2:
            distro = args[0]
            pkg_path = args[1]
        else:
            self.error("Too many arguments to AddDistro")

        pkginfo_file = self.write_pkginfo(pkg_path)
        self.store_channel_info(distro, pkginfo_file)


    def post_process(self):
        pass


    def get_channel_xml(self):
        return self.__channel_xml

